'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = getCommand;

var _env = require('../utils/env');

var _env2 = _interopRequireDefault(_env);

var _query = require('../utils/query');

var _query2 = _interopRequireDefault(_query);

var _constants = require('../utils/constants');

var _print = require('../utils/print');

var _helpers = require('../utils/helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var handlers = {
	account: function account(_account) {
		return _query2.default.isAccountQuery(_account);
	},
	address: function address(_address) {
		return _query2.default.isAccountQuery(_address);
	},
	block: function block(_block) {
		return _query2.default.isBlockQuery(_block);
	},
	delegate: function delegate(_delegate) {
		return _query2.default.isDelegateQuery(_delegate);
	},
	transaction: function transaction(_transaction) {
		return _query2.default.isTransactionQuery(_transaction);
	}
}; /*
    * LiskHQ/lisky
    * Copyright © 2017 Lisk Foundation
    *
    * See the LICENSE file at the top-level directory of this distribution
    * for licensing information.
    *
    * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
    * no part of this software, including this file, may be copied, modified,
    * propagated, or distributed except according to the terms contained in the
    * LICENSE file.
    *
    * Removal or modification of this copyright notice is prohibited.
    *
    */


var processResult = function processResult(useJsonOutput, vorpal, type, result) {
	var printFn = useJsonOutput ? JSON.stringify : _print.getTableString;
	var resultToPrint = result.error ? result : result[type];
	(0, _print.printResult)(printFn, vorpal, resultToPrint);
	return result;
};

var get = function get(vorpal) {
	return function (_ref) {
		var options = _ref.options,
		    type = _ref.type,
		    input = _ref.input;

		var useJsonOutput = (0, _helpers.shouldUseJsonOutput)(_env2.default, options);

		return _constants.COMMAND_TYPES.includes(type) ? handlers[type](input).then(processResult.bind(null, useJsonOutput, vorpal, (0, _helpers.deAlias)(type))) : Promise.resolve(vorpal.log('Unsupported type.'));
	};
};

function getCommand(vorpal) {
	vorpal.command('get <type> <input>').option('-j, --json', 'Sets output to json').option('--no-json', 'Default: sets output to text. You can change this in the config.js').description('Get information from <type> with parameter <input>. \n Types available: account, address, block, delegate, transaction \n E.g. get delegate lightcurve \n e.g. get block 5510510593472232540').description('Get information from <type> with parameter <input>.\n  Types available: account, address, block, delegate, transaction\n  Example: get delegate lightcurve\n  Example: get block 5510510593472232540').autocomplete(_constants.COMMAND_TYPES).action(get(vorpal));
}