'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = listCommand;

var _env = require('../utils/env');

var _env2 = _interopRequireDefault(_env);

var _query = require('../utils/query');

var _query2 = _interopRequireDefault(_query);

var _print = require('../utils/print');

var _constants = require('../utils/constants');

var _helpers = require('../utils/helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var handlers = {
	addresses: function addresses(address) {
		return _query2.default.isAccountQuery(address);
	},
	accounts: function accounts(_accounts) {
		return _query2.default.isAccountQuery(_accounts);
	},
	blocks: function blocks(_blocks) {
		return _query2.default.isBlockQuery(_blocks);
	},
	delegates: function delegates(_delegates) {
		return _query2.default.isDelegateQuery(_delegates);
	},
	transactions: function transactions(_transactions) {
		return _query2.default.isTransactionQuery(_transactions);
	}
}; /*
    * LiskHQ/lisky
    * Copyright © 2017 Lisk Foundation
    *
    * See the LICENSE file at the top-level directory of this distribution
    * for licensing information.
    *
    * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
    * no part of this software, including this file, may be copied, modified,
    * propagated, or distributed except according to the terms contained in the
    * LICENSE file.
    *
    * Removal or modification of this copyright notice is prohibited.
    *
    */


var processResults = function processResults(useJsonOutput, vorpal, type, results) {
	var printFn = useJsonOutput ? JSON.stringify : _print.getTableString;
	var resultsToPrint = results.map(function (result) {
		return result.error ? result : result[type];
	});
	(0, _print.printResult)(printFn, vorpal, resultsToPrint);
	return results;
};

var list = function list(vorpal) {
	return function (_ref) {
		var type = _ref.type,
		    variadic = _ref.variadic,
		    options = _ref.options;

		var singularType = _constants.SINGULARS[type];
		var useJsonOutput = (0, _helpers.shouldUseJsonOutput)(_env2.default, options);

		var makeCalls = function makeCalls() {
			return variadic.map(function (input) {
				return handlers[type](input);
			});
		};

		return _constants.COMMAND_TYPES.includes(singularType) ? Promise.all(makeCalls()).then(processResults.bind(null, useJsonOutput, vorpal, (0, _helpers.deAlias)(singularType))).catch(function (e) {
			return e;
		}) : Promise.resolve(vorpal.log('Unsupported type.'));
	};
};

function listCommand(vorpal) {
	vorpal.command('list <type> <variadic...>').option('-j, --json', 'Sets output to json').option('-t, --no-json', 'Sets output to text').description('Get information from <type> with parameters <input, input, ...>.  \n Types available: accounts, addresses, blocks, delegates, transactions \n E.g. list delegates lightcurve tosch \n E.g. list blocks 5510510593472232540 16450842638530591789').description('Get information from <type> with parameters <input, input, ...>.\n  Types available: accounts, addresses, blocks, delegates, transactions\n  Example: list delegates lightcurve tosch\n  Example: list blocks 5510510593472232540 16450842638530591789').autocomplete(_constants.COMMAND_TYPES).action(list(vorpal));
}