'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.default = setCommand;

var _os = require('os');

var _os2 = _interopRequireDefault(_os);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _env = require('../utils/env');

var _env2 = _interopRequireDefault(_env);

var _liskInstance = require('../utils/liskInstance');

var _liskInstance2 = _interopRequireDefault(_liskInstance);

var _constants = require('../utils/constants');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var configFilePath = _os2.default.homedir() + '/.lisky/config.json'; /*
                                                                      * LiskHQ/lisky
                                                                      * Copyright © 2017 Lisk Foundation
                                                                      *
                                                                      * See the LICENSE file at the top-level directory of this distribution
                                                                      * for licensing information.
                                                                      *
                                                                      * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                                      * no part of this software, including this file, may be copied, modified,
                                                                      * propagated, or distributed except according to the terms contained in the
                                                                      * LICENSE file.
                                                                      *
                                                                      * Removal or modification of this copyright notice is prohibited.
                                                                      *
                                                                      */


var writeConfigToFile = function writeConfigToFile(newConfig) {
	try {
		_fsExtra2.default.writeJsonSync(configFilePath, newConfig, {
			spaces: '\t'
		});
		return true;
	} catch (e) {
		console.warn('WARNING: Could not write to `' + configFilePath + '`. Your configuration will not be persisted.');
		return false;
	}
};

var checkBoolean = function checkBoolean(value) {
	return ['true', 'false'].includes(value);
};

var setNestedConfigProperty = function setNestedConfigProperty(newValue) {
	return function (obj, pathComponent, i, path) {
		if (i === path.length - 1) {
			// eslint-disable-next-line no-param-reassign
			obj[pathComponent] = newValue;
			return _env2.default;
		}
		return obj[pathComponent];
	};
};

var setBoolean = function setBoolean(variable, path) {
	return function (value) {
		if (!checkBoolean(value)) {
			return 'Cannot set ' + variable + ' to ' + value + '.';
		}

		var newValue = value === 'true';
		path.reduce(setNestedConfigProperty(newValue), _env2.default);

		if (variable === 'testnet') {
			_liskInstance2.default.setTestnet(newValue);
		}

		var writeSuccess = writeConfigToFile(_env2.default);

		if (!writeSuccess && process.argv.length > 2) {
			return 'Could not set ' + variable + ' to ' + value + '.';
		}
		return 'Successfully set ' + variable + ' to ' + value + '.';
	};
};

var handlers = {
	json: setBoolean('json output', ['json']),
	testnet: setBoolean('testnet', ['liskJS', 'testnet'])
};

var set = function set(vorpal) {
	return function (_ref) {
		var variable = _ref.variable,
		    value = _ref.value;

		var returnValue = _constants.CONFIG_VARIABLES.includes(variable) ? handlers[variable](value) : 'Unsupported variable name.';

		return Promise.resolve(vorpal.log(returnValue));
	};
};

function setCommand(vorpal) {
	vorpal.command('set <variable> <value>').description('Set configuration <variable> to <value>. Configuration is persisted in `' + configFilePath + '`.').autocomplete(_constants.CONFIG_VARIABLES).action(set(vorpal));
}