'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _os = require('os');

var _os2 = _interopRequireDefault(_os);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _defaultConfig = require('../../defaultConfig.json');

var _defaultConfig2 = _interopRequireDefault(_defaultConfig);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var configDirName = '.lisky';
var configFileName = 'config.json';
var homedir = _os2.default.homedir();
var configDirPath = homedir + '/' + configDirName;
var configFilePath = configDirPath + '/' + configFileName;

var getReadErrorMessage = function getReadErrorMessage(error, path) {
	if (error.code === 'EACCES') {
		return 'WARNING: Could not read `' + path + '`: permission denied. Using default config instead.';
	}
	if (error.message.match(/JSON/)) {
		return 'WARNING: Config file at `' + path + '` is not valid JSON. Using default config instead.';
	}
	return 'WARNING: Could not read `' + path + '`. Using default config instead.';
};

var getWriteErrorMessage = function getWriteErrorMessage(path) {
	return 'WARNING: Could not write to `' + path + '`. Your configuration will not be persisted.';
};

var checkExists = function checkExists(path) {
	try {
		return _fsExtra2.default.existsSync(path);
	} catch (error) {
		var message = getReadErrorMessage(error, path);
		console.warn(message);
		return false;
	}
};

var initConfigFile = function initConfigFile() {
	var configDirExists = checkExists(configDirPath);

	if (!configDirExists) {
		try {
			_fsExtra2.default.mkdirSync(configDirPath);
		} catch (error) {
			var message = getWriteErrorMessage(configDirPath);
			console.warn(message);
		}
	}

	var configFileExists = checkExists(configFilePath);

	if (!configFileExists) {
		try {
			_fsExtra2.default.writeJsonSync(configFilePath, _defaultConfig2.default, {
				spaces: '\t'
			});
		} catch (error) {
			var _message = getWriteErrorMessage(configFilePath);
			console.warn(_message);
		}
	}
};

var getConfig = function getConfig() {
	try {
		return _fsExtra2.default.readJsonSync(configFilePath);
	} catch (error) {
		var message = getReadErrorMessage(error, configFilePath);
		console.warn(message);
		return _defaultConfig2.default;
	}
};

try {
	initConfigFile();
} catch (error) {
	console.warn('WARNING: Could not write to `' + configFilePath + '`; your configuration will not be persisted.');
}

exports.default = getConfig();